class ApiMsg:
    def __init__(self, response):
        self.apiMessage = response['api:message']
        self.ForDevelopersMode = response


class LinkInfo:
    def __init__(self, response):
        self.ndcId = response['extensions']['linkInfo']['ndcId']
        self.objectId = response['extensions']['linkInfo']['objectId']


class ChatThreads:
    def __init__(self, response):
        self.threads = []
        self.title = []
        self.threadId = []
        self.data = response

    @property
    def ChatThreads(self):
        for O in self.data:
            self.threadId.append(O['threadId'])
            self.title.append(O['title'])
        return self

class LoginInfo:
    def __init__(self, response):
        self.uid = response['auid']
        self.sid = 'sid=' + response['sid']
        self.apiMessage = response['api:message']


class MembersList:
    def __init__(self, response):
        self.data = response
        self.lst = []
        self.uid = []
        self.nickname = []
        self.level = []
        self.icon = []
        self.blogsCount = []
        self.commentsCount = []

    @property
    def MembersList(self):
        for O in self.data:
            self.uid.append(O['uid'])
            self.nickname.append(O['nickname'])
            self.level.append(O['level'])
            self.icon.append(O['icon'])
            self.blogsCount.append(O['blogsCount'])
            self.commentsCount.append(O['commentsCount'])
        return self



from time import time
from uuid import UUID
from os import urandom
from binascii import hexlify


def timestamp():
    return int(time() * 1000)


def uid():
    uuid = str(UUID(hexlify(urandom(16)).decode('ascii')))
    return uuid



from .lib import pack, objects
import requests
import json


class LocalClient:
    def __init__(self, comId: str, sid: str, uid: str):
        self.comId = comId
        self.api = 'https://service.narvii.com/api/v1/'
        self.chat = '/s/chat/thread/'
        self.sid = sid
        self.uid = uid
        self.headers = {
            "NDCDEVICEID": "019B6133991CBC2428F822E55AEF0499B3E674928B3268072CC9381881024F07047DCB9A82899C91B8",
            "NDCAUTH": f'{self.sid}'
        }

    def get_public_chats(self, type: str = 'recommended', start: int = 0, size: int = 25):
        r = requests.get(f'{self.api + self.comId + self.chat}?type=public-all&filterType={type}&start={str(start)}&size={str(size)}',headers=self.headers).text
        request = json.loads(r)
        return objects.ChatThreads(request['threadList']).ChatThreads

    def send_message(self, chatId: str, message: str, type: int = 0, refId: int = pack.timestamp() // 1000):

        data = {
            'content': message,
            'type': type,
            'clientRefId': refId
        }
        data = json.dumps(data)
        r = requests.post(url=f'{self.api + self.comId + self.chat + chatId}/message', data=data, headers=self.headers).text
        request = json.loads(r)
        return objects.ApiMsg(response=request)

    def leave_chat(self, chatId: str):
        r = requests.delete(url=f'{self.api + self.comId + self.chat + chatId}/member/' + self.uid, headers=self.headers).text
        request = json.loads(r)
        return objects.ApiMsg(response=request)

    def join_chat(self, chatId: str):
        r = requests.post(url=f'{self.api + self.comId + self.chat + chatId}/member/' + self.uid, headers=self.headers).text
        request = json.loads(r)
        return objects.ApiMsg(response=request)

    def get_online_members(self, start: int = 0, size: int = 25):
        r = requests.get(f'{self.api + self.comId}/s/live-layer?topic=ndtopic:{self.comId}:online-members&start={str(start)}&size={str(size)}', headers=self.headers).text
        request = json.loads(r)
        return objects.MembersList(request['userProfileList']).MembersList

    def invite_to_chat(self, userId: str, chatId: str):
        data = json.dumps({
            "uids": userId,
        })
        r = requests.post(f"{self.api + self.comId + self.chat + chatId}/member/invite", headers=self.headers, data=data)
        request = json.loads(r.text)
        return objects.ApiMsg(request)

    def voice_invite(self, chatId: str, userId: str):
        data = json.dumps({
            "uid": userId
        })
        r = requests.post(f"{self.api + self.comId + self.chat + chatId}/vvchat-presenter/invite/", headers=self.headers, data=data)
        request = json.loads(r.text)
        return objects.ApiMsg(request)

    # API was Discovered by bovonos
    def invite_by_host(self, chatId: str, userId: [str, list]):
        data = json.dumps({
            "uidList": userId
        })
        r = requests.post(f"{self.api + self.comId + self.chat + chatId}/avchat-members",headers=self.headers, data=data)
        request = json.loads(r.text)
        return objects.ApiMsg(request)

    def start_chat(self, userId: str, content: str):
        data = json.dumps({
            "type": 1,
            "inviteeuids": userId,
            "timestamp": pack.timestamp()
        })
        r = requests.post(f"{self.api + self.comId + self.chat}", headers=self.headers, data=data)
        request = json.loads(r.text)
        return objects.ApiMsg(request)

    def edit_chat(self, chatId: str, content: str, title: str):
        data = json.dumps({
            "content": content,
            "title": title
        })
        r = requests.post(f"{self.api + self.comId + self.chat + chatId}", headers=self.headers, data=data)
        request = json.loads(r.text)
        return objects.ApiMsg(request)



from .Local import LocalClient
from .Global import GlobalClient
from requests import get
from json import loads


try:
    __version__ = '1.2.3'
    __newest__ = loads(get("https://pypi.python.org/pypi/SAmino/json").text)["info"]["version"]
    if __version__ != __newest__:
        print(f"\033[1;33mSAmino New Version!: {__newest__} (Your Using {__version__})\033[1;0m")
except:
    pass


import pathlib
from setuptools import setup, find_packages

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="SAmino",
    version="1.2.3",
    url="https://github.com/SirLez/SAmino",
    download_url="https://github.com/SirLez/SAmino/archive/refs/heads/main.zip",
    description="Amino Bots with python!",
    long_description=README,
    long_description_content_type="text/markdown",
    author="SirLez",
    author_email="SirLezDV@gmail.com",
    license="MIT",
    keywords=[
        'capture',
        'captureS'
        'capture-bot',
        'capture-chat',
        'capture-lib',
        'cptr',
        'cptr.co',
        'api',
        'python',
        'python3',
        'python3.x',
        'SirLez',
        'sirlez',
        'Amino',
        'Amino.py',
        'Amino py',
        'amino',
        'amino py'
        'S-Amino',
        'amino',
        'amino',
        'amino-bot',
        'amino-bots',
        'amino-bot',
        'ndc',
        'narvii.apps',
        'aminoapps',
        'amino-py',
        'amino',
        'amino-bot',
        'narvii',
        'api',
        'python',
        'python3',
        'python3.x',
        'slimakoi',
        'official'
    ],
    include_package_data=True,
    install_requires=[
        'requests',
    ],
    setup_requires=[
        'wheel'
    ],
    packages=find_packages(),
)



from .lib import objects, pack
import requests
import json

refId = 712543354323901337


class GlobalClient:
    def __init__(self, sid: str, uid: str):
        self.deviceId = "019B6133991CBC2428F822E55AEF0499B3E674928B3268072CC9381881024F07047DCB9A82899C91B8"
        self.api = 'https://service.narvii.com/api/v1/'
        self.chat = '/s/chat/thread/'
        self.sid = sid
        self.uid = uid
        self.headers = {
            "NDCDEVICEID": "019B6133991CBC2428F822E55AEF0499B3E674928B3268072CC9381881024F07047DCB9A82899C91B8",
            "NDCAUTH": f'{self.sid}'
        }

    def login(self, email: str, password: str):
        data = json.dumps({
            "email": email,
            "secret": f"0 {password}",
            "deviceID": self.deviceId,
            "clientType": 100,
            "action": "normal",
        })
        request = requests.post(f"{self.api}/g/s/auth/login", headers={
            "NDCDEVICEID": "019B6133991CBC2428F822E55AEF0499B3E674928B3268072CC9381881024F07047DCB9A82899C91B8"
        }, data=data)
        Data = json.loads(request.text)
        if request.status_code != 200: return Data['api:message']
        return objects.LoginInfo(Data)

    def send_message(self, chatId: str, message: str, refId: int = pack.timestamp() // 1000, type: int = 0):
        data = {
            'content': message,
            'type': type,
            'clientRefId': refId
        }
        data = json.dumps(data)
        r = requests.post(url=f'{self.api}g{self.chat + chatId}/message', data=data, headers=self.headers).text
        request = json.loads(r)
        return objects.ApiMsg(response=request)

    def join_chat(self, chatId: str):
        r = requests.post(url=f'{self.api}g{self.chat + chatId}/member/' + self.uid, headers=self.headers).text
        request = json.loads(r)
        return objects.ApiMsg(response=request)

    def leave_chat(self, chatId: str):
        r = requests.delete(url=f'{self.api}g{self.chat + chatId}/member/' + self.uid, headers=self.headers).text
        request = json.loads(r)
        return objects.ApiMsg(response=request)

    def get_from_link(self, link: str):
        r = requests.get(f'{self.api}g/s/link-resolution?q={link}', headers=self.headers).text
        request = json.loads(r)
        return objects.LinkInfo(response=request['linkInfoV2'])
